@@ -21,8 +21,9 @@ def run(label, **kwargs):
     try:
         build_and_run(
             lkt_file="expected_concrete_syntax.lkt",
-            version="<version-number>",
-            build_date="<build-date-number>",
+            version="1.version.number",
+            build_date="build.date.number",
+            types_from_lkt=True,
             **kwargs
         )
     except DiagnosticError:
@@ -32,7 +33,7 @@ def run(label, **kwargs):
 
 
 run("Conflict on version",
-    additional_make_args=["--version=something"],
+    additional_make_args=["--version=1.something"],
     full_error_traces=False)
 run("Conflict on build date",
     additional_make_args=["--build-date=something"],
